@@ -21,6 +21,10 @@ class Configuration(object):
     def override_http_client_configuration(self):
         return self._override_http_client_configuration
 
+    @property
+    def http_call_back(self):
+        return self._http_call_back
+
     @property
     def timeout(self):
         return self._timeout
@@ -49,14 +53,14 @@ class Configuration(object):
     def custom_url(self):
         return self._custom_url
 
-    @property
-    def square_version(self):
-        return self._square_version
-
     @property
     def access_token(self):
         return self._access_token
 
+    @property
+    def square_version(self):
+        return self._square_version
+
     @property
     def additional_headers(self):
         return deepcopy(self._additional_headers)
@@ -67,12 +71,13 @@ class Configuration(object):
 
     def __init__(
         self, http_client_instance=None,
-        override_http_client_configuration=False, timeout=60, max_retries=0,
-        backoff_factor=2,
+        override_http_client_configuration=False, http_call_back=None,
+        timeout=60, max_retries=0, backoff_factor=2,
         retry_statuses=[408, 413, 429, 500, 502, 503, 504, 521, 522, 524],
         retry_methods=['GET', 'PUT'], environment='production',
-        custom_url='https://connect.squareup.com', square_version='2021-12-15',
-        access_token='', additional_headers={}, user_agent_detail=''
+        custom_url='https://connect.squareup.com', access_token='',
+        square_version='2022-03-16', additional_headers={},
+        user_agent_detail=''
     ):
         # The Http Client passed from the sdk user for making requests
         self._http_client_instance = http_client_instance
@@ -80,6 +85,9 @@ class Configuration(object):
         # The value which determines to override properties of the passed Http Client from the sdk user
         self._override_http_client_configuration = override_http_client_configuration
 
+        #  The callback value that is invoked before and after an HTTP call is made to an endpoint
+        self._http_call_back = http_call_back
+
         # The value to use for connection timeout
         self._timeout = timeout
 
@@ -103,26 +111,30 @@ class Configuration(object):
         # Sets the base URL requests are made to. Defaults to `https://connect.squareup.com`
         self._custom_url = custom_url
 
-        # Square Connect API versions
-        self._square_version = square_version
-
         # The OAuth 2.0 Access Token to use for API requests.
         self._access_token = access_token
 
+        # Square Connect API versions
+        self._square_version = square_version
+
         # Additional headers to add to each API request
         self._additional_headers = deepcopy(additional_headers)
 
+        # User agent detail, to be appended with user-agent header.
+        self._user_agent_detail = Configuration.validate_user_agent(user_agent_detail)
+
         # The Http Client to use for making requests.
         self._http_client = self.create_http_client()
 
     def clone_with(self, http_client_instance=None,
-                   override_http_client_configuration=None, timeout=None,
-                   max_retries=None, backoff_factor=None, retry_statuses=None,
-                   retry_methods=None, environment=None, custom_url=None,
-                   square_version=None, access_token=None,
+                   override_http_client_configuration=None, http_call_back=None,
+                   timeout=None, max_retries=None, backoff_factor=None,
+                   retry_statuses=None, retry_methods=None, environment=None,
+                   custom_url=None, access_token=None, square_version=None,
                    additional_headers=None, user_agent_detail=None):
         http_client_instance = http_client_instance or self.http_client_instance
         override_http_client_configuration = override_http_client_configuration or self.override_http_client_configuration
+        http_call_back = http_call_back or self.http_call_back
         timeout = timeout or self.timeout
         max_retries = max_retries or self.max_retries
         backoff_factor = backoff_factor or self.backoff_factor
@@ -130,19 +142,20 @@ class Configuration(object):
         retry_methods = retry_methods or self.retry_methods
         environment = environment or self.environment
         custom_url = custom_url or self.custom_url
-        square_version = square_version or self.square_version
         access_token = access_token or self.access_token
+        square_version = square_version or self.square_version
         additional_headers = additional_headers or self.additional_headers
         user_agent_detail = user_agent_detail or self.user_agent_detail
 
         return Configuration(
             http_client_instance=http_client_instance,
             override_http_client_configuration=override_http_client_configuration,
-            timeout=timeout, max_retries=max_retries,
-            backoff_factor=backoff_factor, retry_statuses=retry_statuses,
-            retry_methods=retry_methods, environment=environment,
-            custom_url=custom_url, square_version=square_version,
-            access_token=access_token, additional_headers=additional_headers,
+            http_call_back=http_call_back, timeout=timeout,
+            max_retries=max_retries, backoff_factor=backoff_factor,
+            retry_statuses=retry_statuses, retry_methods=retry_methods,
+            environment=environment, custom_url=custom_url,
+            access_token=access_token, square_version=square_version,
+            additional_headers=additional_headers,
             user_agent_detail=user_agent_detail
         )
 
@@ -187,3 +200,9 @@ class Configuration(object):
         return APIHelper.append_url_with_template_parameters(
             self.environments[self.environment][server], parameters
         )
+
+    @staticmethod
+    def validate_user_agent(user_agent):
+        if len(user_agent) > 128:
+            raise ValueError('The length of user-agent detail should not exceed 128 characters.') 
+        return user_agent
