@@ -17,8 +17,8 @@ class LaborApiTests(ApiTestBase):
     @classmethod
     def setUpClass(cls):
         super(LaborApiTests, cls).setUpClass()
-        cls.response_catcher = HttpResponseCatcher()
-        cls.controller = LaborApi(cls.config, cls.response_catcher)
+        cls.controller = cls.client.labor
+        cls.response_catcher = cls.controller.http_call_back
 
     # Returns a paginated list of `BreakType` instances for a business.
     def test_list_break_types(self):
